@@ -1,5 +1,4 @@
 import subprocess
-import os
 import requests as req
 import click
 
@@ -10,17 +9,14 @@ app = AppHelper()
 class UpdateApp():
 
     def __init__(self) -> None:
-        try:
-            remote_version = self.__get_remote_version()
+        remote_version = self.__get_remote_version()
 
-            if self.__match_version(remote_version):
-                self.__ask_update(remote_version)
-
-        except:
-            pass
+        if self.__match_version(remote_version):
+            self.__ask_update(remote_version)
 
     def __match_version(self,new_version) -> bool:
 
+        if new_version == None: return False
         if 'beta' in app.version: return False
 
         new_version = new_version.split('.')
@@ -42,9 +38,9 @@ class UpdateApp():
 
     def __update(self, new):
 
-        subprocess.run(["pip", "install", "codeswap"])
         subprocess.run(["pip", "install", f"codeswap=={new}"])
         click.secho('app updated successfully', bg='blue', fg='white')
 
     def __get_remote_version(self):
-        return req.get("https://kndhvh.github.io/codeswap.json").json()['codeswap']
+        try: return req.get("https://kndhvh.github.io/codeswap.json").json()['codeswap']
+        except: return None
